rai\_toolbox.perturbations.uniform\_like\_l1\_n\_ball\_
=======================================================

.. currentmodule:: rai_toolbox.perturbations

.. autofunction:: uniform_like_l1_n_ball_